pub struct Column {
pub name: String,
pub transient: bool,
pub complex: bool,
pub reflexive: bool,
pub ignored: bool,
}Expand description
Column configuration
Fields
name: StringName, header of the column
transient: boolThe field is virtual - it is considered during embedding process, no entity is written for the column
complex: boolThe field is composite, containing multiple entity identifiers separated by space
reflexive: boolThe field is reflexive, which means that it interacts with itself, additional output file is written for every such field
ignored: boolThe field is ignored, no output file is written for the field